{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for PowerShell.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/powershell.xml and 'make bootstrap'.
module Skylighting.Syntax.Powershell (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for PowerShell.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpowershell.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowershell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acmdlets\NUL\NUL\NUL\NUL\NUL\NUL\STX\195\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAdd-Content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSAdd-ADComputerServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/Add-ADDomainControllerPasswordReplicationPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Add-ADFineGrainedPasswordPolicySubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Add-ADGroupMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSAdd-ADPrincipalGroupMembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAdd-BitsFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAdd-ClusterDisk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMAdd-ClusterFileServerRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Add-ClusterGenericApplicationRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSAdd-ClusterGenericScriptRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSAdd-ClusterGenericServiceRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAdd-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAdd-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBAdd-ClusterPrintServerRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Add-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSAdd-ClusterResourceDependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBAdd-ClusterResourceType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAdd-ClusterServerRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBAdd-ClusterSharedVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSAdd-ClusterVirtualMachineRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAdd-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAdd-Content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAdd-History\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAdd-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAdd-Member\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Add-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAdd-NlbClusterNodeDip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAdd-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Add-NlbClusterVip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAdd-PSSnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAdd-Type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBackup-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Block-ClusterAccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Checkpoint-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMClear-ADAccountExpiration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSClear-ClusterDiskReservation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Clear-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rClear-Content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClear-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rClear-History\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nClear-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Clear-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClear-RecycleBin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClear-Variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCompare-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKComplete-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Complete-Transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Connect-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConnect-WSMan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIConvertFrom-Csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEConvertFrom-Json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANConvertFrom-SecureString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ConvertFrom-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNConvertFrom-StringData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fConvert-Path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOConvert-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConvertTo-Csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOConvertTo-Html\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOConvertTo-Json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNConvertTo-SecureString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rConvertTo-Xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCopy-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCopy-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Copy-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDebug-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDebug-Process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODebug-Runspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Disable-ADAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMDisable-ADOptionalFeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDisable-ComputerRestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Disable-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDisable-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Disable-PSBreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Disable-PSRemoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSDisable-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKDisable-RunspaceDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Disable-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Disable-WSManCredSSP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Disconnect-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDisconnect-WSMan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEEnable-ADAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANEnable-ADOptionalFeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNEnable-ComputerRestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Enable-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEnable-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Enable-PSBreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Enable-PSRemoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSEnable-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Enable-RunspaceDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Enable-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Enable-WSManCredSSP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Enter-PSHostProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIEnter-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Exit-PSHostProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExit-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExport-Alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Export-BinaryMiLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExport-Clixml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExport-Console\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExport-Counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExport-Csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Export-FormatData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Export-ModuleMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExport-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFind-Package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Find-PackageProvider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOForEach-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFormat-Custom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFormat-List\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFormat-Table\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFormat-Wide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGet-Acl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGet-ADAccountAuthorizationGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/Get-ADAccountResultantPasswordReplicationPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-ADComputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGet-ADComputerServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Get-ADDefaultDomainPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-ADDomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGet-ADDomainController\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/Get-ADDomainControllerPasswordReplicationPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL4Get-ADDomainControllerPasswordReplicationPolicyUsage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USGet-ADFineGrainedPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Get-ADFineGrainedPasswordPolicySubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-ADForest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-ADGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-ADGroupMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGet-ADOptionalFeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGet-ADOrganizationalUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSGet-ADPrincipalGroupMembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-ADRootDSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Get-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-ADUser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Get-ADUserResultantPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGet-Alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSGet-AppLockerFileInformation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-AppLockerPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMGet-AuthenticodeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-ChildItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMGet-CimAssociatedInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-CimClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGet-CimInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-CimSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-Clipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-ClusterAccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGet-ClusterAvailableDisk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-ClusterLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Get-ClusterNetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGet-ClusterNetworkInterfac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGet-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Get-ClusterOwnerNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Get-ClusterParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-ClusterQuorum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSGet-ClusterResourceDependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#Get-ClusterResourceDependencyReport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGet-ClusterResourceType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGet-ClusterSharedVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-CmsMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGet-ComputerRestorePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Get-ControlPanelItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-Credential\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Culture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGet-Date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGet-Event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-EventSubscriber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-ExecutionPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-FormatData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-GPInheritance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGet-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-GPOReport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-GPPermissions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGet-GPPrefRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-GPRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGet-GPResultantSetOfPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-GPStarterGPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGet-Help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-History\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGet-Host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-HotFix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGet-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGet-ItemPropertyValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGet-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-Location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-Member\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-Module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGet-NlbClusterDriverInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Get-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGet-NlbClusterNodeDip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Get-NlbClusterNodeNetworkInterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGet-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-NlbClusterVip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Get-PackageProvider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-PackageSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Get-PfxCertificate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-PSBreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGet-PSCallStack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-PSDrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKGet-PSHostProcessInfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGet-PSProvider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANGet-PSReadlineKeyHandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Get-PSReadlineOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGet-PSSessionCapability\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBGet-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-PSSnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-Random\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-Runspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-RunspaceDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNGet-ScheduledJobOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGet-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGet-TraceSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGet-Transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGet-TroubleshootingPack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-TypeData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-UICulture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGet-Unique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-Variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGet-WinEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGet-WmiObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEGet-WSManCredSSP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Get-WSManInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Grant-ClusterAccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGroup-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fImport-Alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Import-BinaryMiLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImport-Clixml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOImport-Counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nImport-Csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nImport-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Import-LocalizedData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rImport-Module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNImport-PackageProvider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEImport-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANInstall-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInstall-Package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBInstall-PackageProvider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInvoke-CimMethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInvoke-Command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Invoke-DscResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Invoke-Expression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInvoke-History\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInvoke-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Invoke-RestMethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBInvoke-TroubleshootingPack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Invoke-WebRequest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInvoke-WmiMethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Invoke-WSManAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tJoin-Path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLimit-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeasure-Command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMeasure-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMove-ADDirectoryServer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)Move-ADDirectoryServerOperationMasterRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMove-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Move-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Move-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMove-ClusterSharedVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSMove-ClusterVirtualMachineRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMove-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Move-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONew-ADComputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USNew-ADFineGrainedPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNew-ADGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNew-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNew-ADOrganizationalUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4New-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNew-ADUser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNew-Alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3New-AppLockerPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINew-CimInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONew-CimSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4New-CimSessionOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNew-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNew-Event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNew-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNew-GPLink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNew-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENew-GPStarterGPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNew-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLENew-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONew-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNew-Module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2New-ModuleManifest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SONew-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNew-NlbClusterIpv6Address\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNew-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNew-PSDrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNew-PSRoleCapabilityFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNew-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSNew-PSSessionConfigurationFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3New-PSSessionOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNew-PSTransportOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSNew-PSWorkflowExecutionOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNew-ScheduledJobOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNew-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNew-TimeSpan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNew-Variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3New-WebServiceProxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNew-WinEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1New-WSManInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNNew-WSManSessionOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOut-Default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOut-File\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOut-GridView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOut-Host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOut-Null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOut-Printer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOut-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPop-Location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Protect-CmsMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANPublish-DscConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPush-Location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRead-Host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vReceive-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Receive-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBRegister-ArgumentCompleter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRegister-CimIndicationEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Register-EngineEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Register-ObjectEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegister-PackageSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USRegister-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegister-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Register-WmiEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Remove-ADComputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USRemove-ADComputerServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL2Remove-ADDomainControllerPasswordReplicationPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Remove-ADFineGrainedPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)Remove-ADFineGrainedPasswordPolicySubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORemove-ADGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Remove-ADGroupMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRemove-ADOrganizationalUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Remove-ADPrincipalGroupMembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBRemove-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRemove-ADUser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Remove-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Remove-CimInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Remove-CimSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORemove-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Remove-ClusterAccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Remove-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Remove-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRemove-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL Remove-ClusterResourceDependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBRemove-ClusterResourceType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBRemove-ClusterSharedVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemove-Event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRemove-GPLink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRemove-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBRemove-GPPrefRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRemove-GPRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRemove-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Remove-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRemove-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Remove-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRemove-Module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Remove-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRemove-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANRemove-NlbClusterNodeDip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMRemove-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Remove-NlbClusterVip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Remove-PSBreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORemove-PSDrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCRemove-PSReadlineKeyHandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERemove-PSSession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-PSSnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-TypeData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRemove-Variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERemove-WmiObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Remove-WSManInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRename-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRename-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nRename-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRename-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Rename-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBRepair-ClusterSharedVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSReset-ADServiceAccountPassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSReset-ComputerMachinePassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fResolve-Path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERestart-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRestart-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERestore-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERestore-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRestore-GPO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Resume-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Resume-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNResume-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nResume-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Resume-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKResume-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOResume-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSave-Help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSave-Package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESearch-ADAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSelect-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSelect-String\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSelect-Xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESend-MailMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSet-Acl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-ADAccountControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSet-ADAccountExpiration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSet-ADAccountPassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSet-ADComputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Set-ADDefaultDomainPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSet-ADDomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-ADDomainMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USSet-ADFineGrainedPasswordPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSet-ADForest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-ADForestMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSet-ADGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSet-ADObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSet-ADOrganizationalUnit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSet-ADUser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSet-Alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Set-AppLockerPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSet-AuthenticodeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISet-CimInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSet-Clipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSet-ClusterLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-ClusterOwnerNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-ClusterParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-ClusterQuorum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSet-ClusterResourceDependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSet-Content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSet-Date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL Set-DscLocalConfigurationManager\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Set-ExecutionPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-GPInheritance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSet-GPLink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-GPPermissions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSet-GPPrefRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Set-GPRegistryValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSet-Item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-ItemProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSet-JobTrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSet-Location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSet-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Set-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKSet-NlbClusterNodeDip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSet-NlbClusterPortRule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*Set-NlbClusterPortRuleNodeHandlingPriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL Set-NlbClusterPortRuleNodeWeight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-NlbClusterVip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-PackageSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-PSBreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSet-PSDebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANSet-PSReadlineKeyHandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-PSReadlineOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBSet-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESet-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSet-ScheduledJobOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSet-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSet-StrictMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISet-TraceSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSet-Variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISet-WmiInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Set-WSManInstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Set-WSManQuickConfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fShow-Command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKShow-ControlPanelItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rShow-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSort-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSplit-Path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Start-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStart-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Start-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Start-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKStart-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStart-DscConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStart-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStart-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Start-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStart-Process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStart-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStart-Sleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Start-Transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStart-Transcript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStop-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Stop-ClusterGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStop-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Stop-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStop-Computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStop-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIStop-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Stop-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStop-Process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStop-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIStop-Transcript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Suspend-BitsTransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Suspend-ClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSuspend-ClusterResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSuspend-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Suspend-NlbCluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSuspend-NlbClusterNode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISuspend-Service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTee-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Test-AppLockerPolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTest-Cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCTest-ClusterResourceFailure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBTest-ComputerSecureChannel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITest-Connection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKTest-DscConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Test-ModuleManifest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTest-Path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USTest-PSSessionConfigurationFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTest-WSMan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTrace-Command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUnblock-File\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUndo-Transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBUninstall-ADServiceAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Uninstall-Package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnlock-ADAccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Unprotect-CmsMessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEUnregister-Event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnregister-PackageSource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!Unregister-PSSessionConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUnregister-ScheduledJob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUpdate-ClusterIPResource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)Update-ClusterVirtualMachineConfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Update-FormatData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUpdate-Help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUpdate-List\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUpdate-TypeData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUse-Transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWait-Debugger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWait-Event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWait-Job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWait-Process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWhere-Object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWrite-Debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vWrite-Error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWrite-EventLog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWrite-Host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Write-Information\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWrite-Output\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOWrite-Progress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWrite-Verbose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rWrite-Warning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclhy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcvpa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTepal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQepcsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTepsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTetsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXghy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXicm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXiex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXihy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQipcsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXirm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXiwr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ameasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXndr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnpssc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXogv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXoh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrcjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrcsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrujb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrvpa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsajb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsasv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsujb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTExit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aProcess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFinally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aForEach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQThrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTData\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fDynamicParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUsing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTElse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fInlineScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElseIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bParallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWorkflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1special-variables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$True\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$False\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$Env\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$Null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$^\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$args\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$switch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$matches\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r$LastExitCode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$Error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$StackTrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$HOME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$PsHome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE$ConsoleFileName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$PWD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$ShellId\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$Profile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$Host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$OFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKushort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCmdlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCmdlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\STX\194\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSadd-adcomputerserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL/add-addomaincontrollerpasswordreplicationpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL&add-adfinegrainedpasswordpolicysubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1add-adgroupmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSadd-adprincipalgroupmembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fadd-bitsfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIadd-clusterdisk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMadd-clusterfileserverrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL!add-clustergenericapplicationrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSadd-clustergenericscriptrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSadd-clustergenericservicerole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEadd-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIadd-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBadd-clusterprintserverrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3add-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSadd-clusterresourcedependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBadd-clusterresourcetype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKadd-clusterserverrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBadd-clustersharedvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSadd-clustervirtualmachinerole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fadd-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vadd-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vadd-history\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOadd-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nadd-member\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2add-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKadd-nlbclusternodedip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNadd-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1add-nlbclustervip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fadd-pssnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\badd-type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbackup-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3block-clusteraccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3checkpoint-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMclear-adaccountexpiration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSclear-clusterdiskreservation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1clear-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rclear-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclear-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rclear-history\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nclear-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2clear-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEclear-recyclebin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclear-variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclhy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcompare-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcomplete-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4complete-transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1connect-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconnect-wsman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconvert-path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOconvert-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIconvertfrom-csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEconvertfrom-json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANconvertfrom-securestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2convertfrom-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNconvertfrom-stringdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconvertto-csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOconvertto-html\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOconvertto-json\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNconvertto-securestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconvertto-xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcopy-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcopy-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1copy-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcvpa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdebug-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug-process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug-runspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1disable-adaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMdisable-adoptionalfeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBdisable-computerrestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2disable-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBdisable-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4disable-psbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2disable-psremoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSdisable-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdisable-runspacedebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4disable-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4disable-wsmancredssp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4disconnect-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdisconnect-wsman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXebp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEenable-adaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANenable-adoptionalfeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNenable-computerrestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1enable-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMenable-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3enable-psbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1enable-psremoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSenable-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4enable-runspacedebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3enable-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3enable-wsmancredssp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3enter-pshostprocess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIenter-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTepal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQepcsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTepsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTetsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2exit-pshostprocess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexit-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fexport-alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2export-binarymilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rexport-clixml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexport-console\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOexport-counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexport-csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1export-formatdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3export-modulemember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEexport-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind-package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4find-packageprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOforeach-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rformat-custom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vformat-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fformat-table\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vformat-wide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgci\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aget-acl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USget-adaccountauthorizationgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL/get-adaccountresultantpasswordreplicationpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-adcomputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSget-adcomputerserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL!get-addefaultdomainpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-addomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNget-addomaincontroller\NUL\NUL\NUL\NUL\NUL\NUL\NUL/get-addomaincontrollerpasswordreplicationpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL4get-addomaincontrollerpasswordreplicationpolicyusage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USget-adfinegrainedpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL&get-adfinegrainedpasswordpolicysubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-adforest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-adgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-adgroupmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKget-adoptionalfeature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANget-adorganizationalunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSget-adprincipalgroupmembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-adrootdse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4get-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-aduser\NUL\NUL\NUL\NUL\NUL\NUL\NUL!get-aduserresultantpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tget-alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSget-applockerfileinformation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-applockerpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMget-authenticodesignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-childitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMget-cimassociatedinstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-cimclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIget-ciminstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-cimsession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-clipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-clusteraccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANget-clusteravailabledisk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-clusterlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2get-clusternetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBget-clusternetworkinterfac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIget-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4get-clusterownernode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4get-clusterparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-clusterquorum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSget-clusterresourcedependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL#get-clusterresourcedependencyreport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBget-clusterresourcetype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBget-clustersharedvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-cmsmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANget-computerrestorepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4get-controlpanelitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-credential\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-culture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget-date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tget-event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-eventsubscriber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-executionpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-formatdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-gpinheritance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aget-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-gporeport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-gppermissions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBget-gpprefregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-gpregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBget-gpresultantsetofpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-gpstartergpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget-help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-history\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget-host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-hotfix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKget-itempropertyvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aget-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-member\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANget-nlbclusterdriverinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2get-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKget-nlbclusternodedip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"get-nlbclusternodenetworkinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNget-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-nlbclustervip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3get-packageprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-packagesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2get-pfxcertificate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-psbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIget-pscallstack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-psdrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKget-pshostprocessinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOget-psprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANget-psreadlinekeyhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4get-psreadlineoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBget-pssessioncapability\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBget-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-pssnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-random\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-runspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-runspacedebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNget-scheduledjoboption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vget-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIget-tracesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIget-transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBget-troubleshootingpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-typedata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-uiculture\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nget-unique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fget-winevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rget-wmiobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEget-wsmancredssp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1get-wsmaninstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXghy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3grant-clusteraccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgroup-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXicm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXiex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXihy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fimport-alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2import-binarymilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rimport-clixml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimport-counter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimport-csv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nimport-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4import-localizeddata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rimport-module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNimport-packageprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEimport-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANinstall-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIinstall-package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBinstall-packageprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinvoke-cimmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinvoke-command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2invoke-dscresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1invoke-expression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinvoke-history\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinvoke-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1invoke-restmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBinvoke-troubleshootingpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1invoke-webrequest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinvoke-wmimethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2invoke-wsmanaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQipcsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTipsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXirm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXise\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXiwr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjoin-path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlimit-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ameasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeasure-command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmeasure-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNmove-addirectoryserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL)move-addirectoryserveroperationmasterrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmove-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1move-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4move-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANmove-clustersharedvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSmove-clustervirtualmachinerole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmove-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1move-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXndr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnew-adcomputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USnew-adfinegrainedpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnew-adgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnew-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANnew-adorganizationalunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4new-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnew-aduser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnew-alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3new-applockerpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SInew-ciminstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnew-cimsession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4new-cimsessionoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnew-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnew-event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnew-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnew-gplink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anew-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnew-gpstartergpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnew-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEnew-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnew-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnew-module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2new-modulemanifest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnew-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMnew-nlbclusteripv6address\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnew-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnew-psdrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANnew-psrolecapabilityfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnew-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSnew-pssessionconfigurationfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3new-pssessionoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKnew-pstransportoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSnew-psworkflowexecutionoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnew-scheduledjoboption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnew-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnew-timespan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnew-variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3new-webserviceproxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnew-winevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1new-wsmaninstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNnew-wsmansessionoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnpssc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXogv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXoh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vout-default\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bout-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fout-gridview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bout-host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bout-null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vout-printer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nout-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpop-location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2protect-cmsmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpublish-dscconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpush-location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrcjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrcsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrdr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tread-host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreceive-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1receive-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBregister-argumentcompleter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCregister-cimindicationevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4register-engineevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4register-objectevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregister-packagesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USregister-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKregister-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1register-wmievent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1remove-adcomputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USremove-adcomputerserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL2remove-addomaincontrollerpasswordreplicationpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"remove-adfinegrainedpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL)remove-adfinegrainedpasswordpolicysubject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOremove-adgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4remove-adgroupmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCremove-adorganizationalunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL!remove-adprincipalgroupmembership\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBremove-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rremove-aduser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3remove-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2remove-ciminstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1remove-cimsession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOremove-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4remove-clusteraccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3remove-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2remove-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNremove-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL remove-clusterresourcedependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBremove-clusterresourcetype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBremove-clustersharedvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fremove-event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rremove-gplink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nremove-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBremove-gpprefregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNremove-gpregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vremove-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3remove-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nremove-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1remove-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rremove-module\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1remove-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKremove-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANremove-nlbclusternodedip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMremove-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4remove-nlbclustervip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3remove-psbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOremove-psdrive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCremove-psreadlinekeyhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEremove-pssession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-pssnapin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-typedata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIremove-variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEremove-wmiobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4remove-wsmaninstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrename-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrename-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrename-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrename-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3rename-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBrepair-clustersharedvolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSreset-adserviceaccountpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSreset-computermachinepassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fresolve-path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErestart-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrestart-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErestore-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErestore-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrestore-gpo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3resume-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2resume-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNresume-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresume-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1resume-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKresume-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOresume-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrmo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrni\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrsnp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrujb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrvpa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrwmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsajb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsasv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsave-help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsave-package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsbp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsearch-adaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rselect-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rselect-string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nselect-xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsend-mailmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aset-acl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-adaccountcontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBset-adaccountexpiration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKset-adaccountpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOset-adcomputer\NUL\NUL\NUL\NUL\NUL\NUL\NUL!set-addefaultdomainpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset-addomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-addomainmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USset-adfinegrainedpasswordpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset-adforest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-adforestmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vset-adgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset-adobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANset-adorganizationalunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nset-aduser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tset-alias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3set-applockerpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMset-authenticodesignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIset-ciminstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rset-clipboard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOset-clusterlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-clusterownernode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-clusterparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-clusterquorum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSset-clusterresourcedependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vset-content\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bset-date\NUL\NUL\NUL\NUL\NUL\NUL\NUL set-dsclocalconfigurationmanager\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3set-executionpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-gpinheritance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nset-gplink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-gppermissions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBset-gpprefregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3set-gpregistryvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bset-item\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-itemproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOset-jobtrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset-location\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOset-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2set-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKset-nlbclusternodedip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNset-nlbclusterportrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL*set-nlbclusterportrulenodehandlingpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL set-nlbclusterportrulenodeweight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-nlbclustervip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-packagesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-psbreakpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vset-psdebug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANset-psreadlinekeyhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-psreadlineoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBset-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEset-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNset-scheduledjoboption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vset-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOset-strictmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIset-tracesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset-variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIset-wmiinstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1set-wsmaninstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4set-wsmanquickconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshow-command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKshow-controlpanelitem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rshow-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsort-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsplit-path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2start-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstart-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2start-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1start-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstart-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNstart-dscconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstart-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstart-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4start-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstart-process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstart-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstart-sleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1start-transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstart-transcript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstop-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1stop-clustergroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstop-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4stop-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstop-computer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstop-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstop-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3stop-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstop-process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstop-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstop-transcript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsujb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4suspend-bitstransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3suspend-clusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBsuspend-clusterresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsuspend-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2suspend-nlbcluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNsuspend-nlbclusternode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsuspend-service\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTswmi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntee-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4test-applockerpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftest-cluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCtest-clusterresourcefailure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBtest-computersecurechannel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItest-connection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtest-dscconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3test-modulemanifest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttest-path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\UStest-pssessionconfigurationfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntest-wsman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtrace-command\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrcm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funblock-file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEundo-transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBuninstall-adserviceaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1uninstall-package\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEunlock-adaccount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4unprotect-cmsmessage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEunregister-event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANunregister-packagesource\NUL\NUL\NUL\NUL\NUL\NUL\NUL!unregister-pssessionconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBunregister-scheduledjob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANupdate-clusteripresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL)update-clustervirtualmachineconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1update-formatdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vupdate-help\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vupdate-list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIupdate-typedata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIuse-transaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwait-debugger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwait-event\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwait-job\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwait-process\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwhere-object\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwjb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwrite-debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vwrite-error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwrite-eventlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwrite-host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1write-information\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwrite-output\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOwrite-progress\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwrite-verbose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rwrite-warning\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH#>\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereStringer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereStringer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\"@\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\b[_\\w][_\\w\\d]*(?=[\\s]*)\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdynamicparam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afinally\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finlinescript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQparam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprocess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bworkflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQulong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKushort\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCmdlet\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStringQ\SOH@\"\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereStringer\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 1\SOH<#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommentar 2\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b\\$(global|script)(?=\\s+(:))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\$+[a-zA-Z_\\x7f-\\xff][a-zA-Z0-9_\\x7f-\\xff]*\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\t\n !%&()*+,./;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$?\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$^\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX$_\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$args\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE$consolefilename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$env\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$error\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$false\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$home\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$host\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK$input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r$lastexitcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$matches\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$null\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$ofs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$profile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$pshome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$pwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b$shellid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v$stacktrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a$switch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ$true\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMember\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK!%&()*+,-/:;<=>?[]^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringEscape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH$_\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH${\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\SO\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#`[`\"0abefnrtv\\$]|`u\\{[0-9A-Fa-f]+\\}\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStringQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStringQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringEscape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULZMotoki Kashihara (motoki8791@gmail.com); Michael Lombardi (Michael.T.Lombardi@outlook.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ps1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.psm1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.psd1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
